@@ -1034,6 +1034,10 @@ def overall_statistics(**kwargs):
     result["SOA4(Cicchetti)"] = kappa_analysis_cicchetti(result["Kappa"])
     result["SOA5(Cramer)"] = V_analysis(result["Cramer V"])
     result["SOA6(Matthews)"] = MCC_analysis(result["Overall MCC"])
+    result["SOA7(Lambda A)"] = lambda_analysis(result["Lambda A"])
+    result["SOA8(Lambda B)"] = lambda_analysis(result["Lambda B"])
+    result["SOA9(Krippendorff Alpha)"] = alpha_analysis(result["Krippendorff Alpha"])
+    result["SOA10(Pearson C)"] = pearson_C_analysis(result["Pearson C"])
     result["FPR Macro"] = complement(result["TNR Macro"])
     result["FNR Macro"] = complement(result["TPR Macro"])
     result["PPV Macro"] = macro_calc(kwargs["PPV"])
